# To build run: QA_RPATHS=0x0001 rpmbuild -ba --sign SPECS/vlc.spec

Name:		vlc
Version:	2.0.0
Release:	2%{?dist}

Summary:	Video Lan Client - a multimedia player, streamer and framework
Group:		Applications/Multimedia
License:	GPLv2+ and LGPLv2.1+
URL:		http://www.videolan.org/vlc/
Source0:	http://download.videolan.org/pub/videolan/vlc/%{version}/vlc-%{version}.tar.xz
# we include libxcb 1.7 statically as >= 1.6 required and RHEL6 only ships 1.5
Source1:	http://xcb.freedesktop.org/dist/libxcb-1.7.tar.bz2
# fix default fonts
Patch0:		vlc-2.0.0-fix-default-font.patch
BuildRequires:	libvorbis-devel, libogg-devel, libtheora-devel, speex-devel
BuildRequires:	flac-devel, x264-devel, a52dec-devel, libmpeg2-devel
BuildRequires:	faad2-devel, faac-devel, lame-devel, libdvdcss-devel
BuildRequires:	ffmpeg-devel, libmad-devel, orc, orc-devel, gnutls-devel
BuildRequires:	schroedinger-devel, libdca-devel, twolame-devel, lua-devel
BuildRequires:	libmpcdec-devel, libass-devel, libebml-devel, libmatroska-devel
BuildRequires:	libdvbpsi-devel, libmodplug-devel, libshout-devel, live555-devel
BuildRequires:	libdvdread-devel, libdvdnav-devel, libcddb-devel, libcdio-devel
BuildRequires:	vcdimager-devel, libgpg-error-devel, libgcrypt-devel, SDL-devel
BuildRequires:	libxml2-devel, libpng-devel, libjpeg-devel, libtiff-devel
BuildRequires:	SDL_image-devel, zlib-devel, fribidi-devel, freetype-devel
BuildRequires:	taglib-devel, libupnp-devel, expat-devel, sqlite-devel
BuildRequires:	gettext-devel, pkgconfig, libtool, autoconf, automake, yasm
BuildRequires:	xcb-util-devel, libtar-devel, libproxy-devel, libbluray-devel
BuildRequires:	alsa-lib-devel, dbus-devel, libv4l-devel, minizip-devel
BuildRequires:	libssh2-devel, libkate-devel, libcrystalhd-devel, libva-freeworld-devel
BuildRequires:	libmtp-devel
BuildRequires:	xcb-proto, ncurses-devel
BuildRequires:	libsmbclient-devel
BuildRequires:	qt4-devel
Requires:	kde-filesystem
Provides:	vlc-core   = %{version}-%{release}
Provides:	vlc-extras = %{version}-%{release}
Obsoletes:	vlc-core   < %{version}-%{release}
Obsoletes:	vlc-extras < %{version}-%{release}
Obsoletes:	vlc-plugin-jack, vlc-plugin, mozilla-vlc


%description
VLC is a free and open source cross-platform multimedia player and framework
that plays most multimedia files as well as DVD, Audio CD, VCD, and various
streaming protocols.


%package devel
Group:		Development/Libraries
Summary:	Include files needed for development with libvlc
Requires:	%{name} = %{version}-%{release}


%description devel
This package contains the files necessary for development with libvlc.


%prep
%setup -q
%patch0 -p1 -b .font


%build
cd contrib/
# fix broken path structure
mv src/src src2 ; rmdir src ; mv src2 src
# remove contrib dependency from xcb
sed -i 's|^DEPS_xcb =.*|DEPS_xcb =|g' src/xcb/rules.mak
# the following xcb features need to be built too
sed -i 's|--disable-render|--enable-render|g' src/xcb/rules.mak
sed -i 's|--disable-shape|--enable-shape|g' src/xcb/rules.mak
sed -i 's|--disable-xfixes|--enable-xfixes|g' src/xcb/rules.mak
# remove all other contrib builds
rm -f `ls -d src/*/rules.mak|grep -v xcb`
# build xcb 1.7
mkdir native ; cd native/
../bootstrap
sed -i 's|^PKGS_ENABLE :=|PKGS_ENABLE := xcb|g' config.mak
cp %{SOURCE1} ../tarballs/
make CFLAGS="%{optflags}"
cd ../..
# fix broken check for live555
sed -i 's|if test -z "\${CONTRIB_DIR}"|if test ! -d "${CONTRIB_DIR}/include/liveMedia"|g' configure
# main vlc build
%configure \
    --enable-shared \
    --disable-static \
    --disable-rpath \
    --disable-optimizations \
    --enable-mmx \
    --enable-sse \
    --enable-ncurses \
    --enable-pvr \
    --enable-faad \
    --enable-sftp \
    --enable-kate
make


%install
rm -rf %{buildroot}
make install DESTDIR="%{buildroot}"
find %{buildroot}%{_libdir}/ -name "lib*.la" -exec rm -f {} \;
mv %{buildroot}%{_docdir}/%{name} _doc
%find_lang %{name}


%clean
rm -rf %{buildroot}


%post
/sbin/ldconfig
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi
%{_bindir}/update-desktop-database %{_datadir}/applications &>/dev/null || :


%postun
/sbin/ldconfig
%{_bindir}/update-desktop-database %{_datadir}/applications &>/dev/null
touch --no-create %{_datadir}/icons/hicolor
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor
fi || :


%posttrans
%{_libdir}/vlc/vlc-cache-gen -f %{_libdir}/vlc &>/dev/null || :


%files -f %{name}.lang
%defattr(-,root,root,0755)
%doc AUTHORS COPYING COPYING.LIB NEWS README THANKS
%{_bindir}/vlc
%{_bindir}/cvlc
%{_bindir}/nvlc
%{_bindir}/rvlc
%{_bindir}/qvlc
%{_bindir}/vlc-wrapper
%{_libdir}/libvlc*so.*
%{_libdir}/vlc/
%{_datadir}/vlc/
%{_datadir}/applications/vlc.desktop
%{_datadir}/icons/hicolor/*/apps/vlc*.png
%{_datadir}/icons/hicolor/*/apps/vlc*.xpm
%{_datadir}/kde4/apps/solid/actions/vlc-*.desktop
%{_mandir}/man1/vlc.1.gz
%{_mandir}/man1/vlc-wrapper.1.gz


%files devel
%defattr(-,root,root,0755)
%doc _doc/* ChangeLog
%{_includedir}/vlc/
%{_libdir}/libvlc*.so
%{_libdir}/pkgconfig/libvlc.pc
%{_libdir}/pkgconfig/vlc-plugin.pc


%changelog
* Fri Apr 27 2012 Nux <rpm@li.nux.ro> - 2.0.0-2
- adopted in nux-dextop repo, modified requires accordingly
- added support for ncurses and samba

* Wed Feb 29 2012 LTN Packager <packager-el6rpms@LinuxTECH.NET> - 2.0.0-2
- added patch to fix default hard-coded fonts
- enabled sftp and kate plugins
- added a few missing build dependencies

* Wed Feb 22 2012 LTN Packager <packager-el6rpms@LinuxTECH.NET> - 2.0.0-1
- initial package release

